@@ -2,7 +2,7 @@ package App::Yath::Command;
 use strict;
 use warnings;
 
-our $VERSION = '0.001043';
+our $VERSION = '0.001044';
 
 use Carp qw/croak confess/;
 use File::Temp qw/tempdir/;
@@ -84,6 +84,12 @@ sub init {
         return;
     }
 
+    if ($settings->{version}) {
+        delete $settings->{quiet};
+        $self->paint($self->version_details);
+        return;
+    }
+
     die "You cannot select both bzip2 and gzip for the log.\n"
         if $settings->{bzip2_log} && $settings->{gzip_log};
 
@@ -210,7 +216,7 @@ sub pre_run {
 
     # init() will already have printed the help message
     # so there is nothing more to do
-    return 0 if $settings->{help};
+    return 0 if $settings->{help} || $settings->{version};
 
     $self->inject_signal_handlers();
 
@@ -296,6 +302,24 @@ sub options {
             summary => ['Exit after showing this help message'],
         },
 
+        {
+            spec    => 'h|help',
+            field   => 'help',
+            used_by => {all => 1},
+            section => 'Help',
+            usage   => ['-h  --help'],
+            summary => ['Exit after showing this help message'],
+        },
+
+        {
+            spec    => 'V|version',
+            field   => 'version',
+            used_by => {all => 1},
+            section => 'Help',
+            usage   => ['-V --version'],
+            summary => ['Show version information'],
+        },
+
         {
             spec    => 'I|include=s@',
             field   => 'libs',
@@ -1088,6 +1112,31 @@ $options
     return $usage;
 }
 
+sub version_details {
+    my $self = shift;
+
+    require Test2::Util::Table;
+
+    my $out = <<"    EOT";
+
+Yath version: $VERSION
+
+Other version info:
+    EOT
+
+    my @vers = (
+        [perl => $^V],
+        map {eval "require $_;" && [$_ => $_->VERSION]} qw/App::Yath Test2::Harness Test2::Suite Test2::API Test::Builder/
+    );
+
+    $out .= join "\n" => Test2::Util::Table::table(
+        header => [qw/COMPONENT VERSION/],
+        rows   => \@vers,
+    );
+
+    return "$out\n\n";
+}
+
 sub loggers {
     my $self     = shift;
     my $settings = $self->{+SETTINGS};
