@@ -2,7 +2,7 @@ package App::Yath::Command::test;
 use strict;
 use warnings;
 
-our $VERSION = '0.001043';
+our $VERSION = '0.001044';
 
 use Test2::Harness::Util::TestFile;
 use Test2::Harness::Feeder::Run;
@@ -370,6 +370,10 @@ sub run_command {
     # Possible failure causes
     my $fail = $lost || $exit || !defined($exit) || !$ok || !$stat;
 
+    for my $plugin (@{$self->{+PLUGINS}}) {
+        $plugin->post_run(command => $self, settings => $settings, stat => $stat);
+    }
+
     if (@$bad) {
         $self->paint("\nThe following test jobs failed:\n");
         $self->paint("  [", $_->{job_id}, '] ', File::Spec->abs2rel($_->file), "\n") for sort {
@@ -621,6 +625,18 @@ Exit after showing what yath thinks your options mean
 
 Exit after showing this help message
 
+=item -h
+
+=item --help
+
+Exit after showing this help message
+
+=item -V
+
+=item --version
+
+Show version information
+
 =back
 
 =head2 Harness Options
